# This file was auto-generated by Fern from our API Definition.

import typing

from .inference_create_by_prompt_id import InferenceCreateByPromptId
from .inference_create_by_prompt_version_id import InferenceCreateByPromptVersionId

NewInferenceRequest = typing.Union[InferenceCreateByPromptVersionId, InferenceCreateByPromptId]
